@@ -5,138 +5,6 @@ options(pager = "console")
 library('doBy')
 
 assign(".oldSearch", search(), pos = 'CheckExEnv')
-cleanEx()
-nameEx("KenRog-Primitive")
-### * KenRog-Primitive
-
-flush(stderr()); flush(stdout())
-
-### Name: KenwardRoger primitive function
-### Title: Ftest and degrees of freedom based on Kenward-Roger
-###   approximation
-### Aliases: .KRmodcompPrimitive
-### Keywords: function
-
-### ** Examples
-
-     ## save all data
-	 x<-3
-	 
-
-
-cleanEx()
-nameEx("KenRog-linearAlgebra")
-### * KenRog-linearAlgebra
-
-flush(stderr()); flush(stdout())
-
-### Name: linearAlgebra
-### Title: Linear Algebra
-### Aliases: spur spurAB fatAB fatBL orthComplement
-### Keywords: file
-
-### ** Examples
-
-     ## save all data
-	 x<-3
-	 
-
-
-cleanEx()
-nameEx("KenRog")
-### * KenRog
-
-flush(stderr()); flush(stdout())
-
-### Name: KenwardRoger
-### Title: Ftest and degrees of freedom based on Kenward-Roger
-###   approximation
-### Aliases: KRmodcomp KRmodcomp.mer print.KRmodcomp
-### Keywords: function
-
-### ** Examples
-
-(fmLarge <- lmer(Reaction ~ Days + (Days|Subject), sleepstudy))
-#removing Day
-(fmSmall <- lmer(Reaction ~ 1 + (Days|Subject), sleepstudy))
-(KRmodcomp(fmLarge,fmSmall))
-# the same test using a restriction matrix
-L<-cbind(0,1)
-(KRmodcomp(fmLarge,L))
-
-
-
-cleanEx()
-nameEx("PB_PBmodcomp")
-### * PB_PBmodcomp
-
-flush(stderr()); flush(stdout())
-
-### Name: PBmodcomp
-### Title: Model comparison of mixed models using parametric bootstrap
-###   methods.
-### Aliases: PBmodcomp PBmodcomp.mer BCmodcomp BCmodcomp.mer
-###   as.data.frame.XXmodcomp print.XXmodcomp
-### Keywords: utilities models inference
-
-### ** Examples
-
-library(doBy)
-data(beets)
-head(beets)
-beet0<-lmer(sugpct~block+sow+harvest+(1|block:harvest), data=beets, REML=FALSE)
-beet_no.harv <- update(beet0, .~.-harvest)
-BCmodcomp(beet0, beet_no.harv, nsim=20)
-
-## Not run: 
-##D ## Vanilla
-##D PBmodcomp(beet0, beet_no.harv)
-##D BCmodcomp(beet0, beet_no.harv)
-##D ## Simulate reference distribution separately:
-##D rr <- PBrefdist(beet0, beet_no.harv, nsim=20)
-##D PBmodcomp(beet0, beet_no.harv, ref=rr)
-##D BCmodcomp(beet0, beet_no.harv, ref=rr)
-## End(Not run)
-
-
-
-
-cleanEx()
-nameEx("PB_PBrefdist")
-### * PB_PBrefdist
-
-flush(stderr()); flush(stdout())
-
-### Name: PBrefdist
-### Title: Calculate reference distribution using parametric bootstrap
-### Aliases: PBrefdist PBrefdist.mer
-### Keywords: utilities models
-
-### ** Examples
-
-library(doBy)
-data(beets)
-head(beets)
-beet0<-lmer(sugpct~block+sow+harvest+(1|block:harvest), data=beets, REML=FALSE)
-beet_no.harv <- update(beet0, .~.-harvest)
-rr <- PBrefdist(beet0, beet_no.harv, nsim=20)
-rr
-
-## Note clearly many more than 10 simulations must be made in practice.
-
-## Computations can be made in parallel using several processors:
-## Not run: 
-##D library(snow)
-##D cl <- makeSOCKcluster(rep("localhost", 4))
-##D clusterEvalQ(cl, library(lme4))
-##D clusterSetupSPRNG(cl)
-##D rr <- PBrefdist(beet0, beet_no.harv, nsim=20)
-##D stopCluster(cl)
-## End(Not run)
-## Above, 4 cpu's are used and 5 simulations are made on each cpu.
-
-
-
 cleanEx()
 nameEx("Rscript2HTML")
 ### * Rscript2HTML
@@ -472,7 +340,8 @@ flush(stderr()); flush(stdout())
 
 ### Name: popMeans
 ### Title: Calculate population means (LSMEANS in SAS jargon)
-### Aliases: popMeans popMeans.lm lsMeans lsMeans.lm summary.conMeans
+### Aliases: popMeans popMeans.lm popMeans.mer lsMeans lsMeans.lm
+###   lsMeans.mer summary.conMeans
 ### Keywords: models utilites
 
 ### ** Examples
@@ -647,6 +516,35 @@ sampleBy(formula = ~Evit+Cu, frac=.1, data = dietox)
 
 
 
+cleanEx()
+nameEx("scaleBy")
+### * scaleBy
+
+flush(stderr()); flush(stdout())
+
+### Name: scaleBy
+### Title: Groupwise scaling and centering of numeric columns in a
+###   dataframe
+### Aliases: scaleBy
+### Keywords: utilities
+
+### ** Examples
+
+
+data(dietox)
+
+# "Remove" the effect of time by centering data within each time point.
+dietox2 <- scaleBy(Weight~Time, data=dietox, scale=FALSE)
+
+## Not run: 
+##D library(lattice)
+##D xyplot(Weight~Time|Evit+Cu, groups=Pig, data=dietox)
+##D xyplot(Weight~Time|Evit+Cu, groups=Pig, data=dietox2)
+## End(Not run)
+
+
+
+
 cleanEx()
 nameEx("splitBy")
 ### * splitBy
